//--------------------------------------------------------------------
//                                                                    
//  Module:       PartialKeyResultList                                       
//  Description:  PartialKeyResultList
//                                                                    
//--------------------------------------------------------------------

import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import java.util.*;
import java.io.*;
import java.net.*;


public class PartialKeyResultList extends JDPClassLayout  {

	JDPUser user;
	JDPJagg jaggSQL;
	JDPPopupMessage popuppanel;
	JDPMaskEdit JDPMaskEditMain;
	String moduleParameter;
	//
	//  Declare screen components
	//
	Panel Main;
	JDPTextGrid DetailGrid1;
	JDPSearchResults ResultList1;

	public void InitClass(JDPUser user, Panel targetPanel, String moduleParameter) {

		this.user = user;
		this.moduleParameter = moduleParameter;
		//
		//  Set JAGG settings for this class
		//
		jaggSQL = new JDPJagg(user.jaggPath);

		setLayout(new BorderLayout());
		popuppanel = new JDPPopupMessage(user,this);
		add(popuppanel);
		JDPMaskEditMain = new JDPMaskEdit();

		CheckboxGroup cbGroup4 = new CheckboxGroup();
		Main = new Panel();
		DetailGrid1Main();
		ResultList1Main();

		Main.setLayout(new BorderLayout());
		add("Center", Main);
		Main.add("Center", DetailGrid1);
		Main.add("West", ResultList1);



		//
		//  Initialise Components
		//
		InitComponents();
		//
		//  Add the handle to this panel to the global vector so other panels can
		//  access this one
		//
		user.gParm.addElement(this);
	}

	//
	//  Handle screen events
	//
	public boolean handleEvent(Event e) {

		switch (e.id) {
		case Event.ACTION_EVENT:
			if (e.target.equals(ResultList1)) {
				DetailGrid1LoadGrid(ResultList1.getSelectedKey());
				return true;
			}
			return false;

		case Event.LIST_SELECT:
			if (e.target.equals(ResultList1)) {
				if (!e.arg.equals("BranchOpen")) {
					String[] keys = ResultList1.getSelectedKey();
					for (int ix=ResultList1.tree.getSelectedLvl(); ix<keys.length; ix++) {
						keys[ix] = null;
					}
					DetailGrid1LoadGrid(keys);
				}
				return true;
			}
			return false;

		case Event.MOUSE_MOVE:
		case Event.MOUSE_ENTER:
		case Event.MOUSE_EXIT:
			popuppanel.postEvent(e);
			return false;

		default:
			return false;

		}
	}


	//
	//  Initialise other components by calling their methods
	//
	public void InitComponents() {

		

	}
	//
	//  Main initialization method
	//
	public void DetailGrid1Main() {

		DetailGrid1SetGridSettings();

	}

	//
	//  Load the grid with the specified parameters and selected data
	//
	public void DetailGrid1LoadGrid(String[] keys) {

		JDPTextGrid tableContents = DetailGrid1;

		if (keys == null || keys.length < 0) {
			DetailGrid1LoadEmptyGrid();
			return;
		}

		StringTokenizer stok;
		int recCount = 0;
		Vector results = new Vector();
		String sep = jaggSQL.getSEP();
		int actualRows = 0;
		String row;
		int columnCount = 6;

		Vector columns = new Vector();
		Vector indexes = new Vector();

		String SQL = "SELECT stor_id, " +
					"ord_num, " +
					"title_id, " +
					"stor_id, " +
					"ord_num, " +
					"format(ord_date, 'mm/dd/yy'), " +
					"qty, " +
					"payterms, " +
					"title_id FROM dbo_sales WHERE (1=1)  ";
		if (keys.length > 0 && keys[0] != null) SQL += " AND stor_id='" + keys[0]+ "'" ;
		if (keys.length > 1 && keys[1] != null) SQL += " AND ord_num='" + keys[1]+ "'" ;
		if (keys.length > 2 && keys[2] != null) SQL += " AND title_id='" + keys[2]+ "'" ;

		user.mainmsg.setStatusMsg("Accessing database...", 0);

		jaggSQL.setDSN("JDP Tutorial");
		jaggSQL.setJdbcDriver("sun.jdbc.odbc.JdbcOdbcDriver");
		jaggSQL.setJdbcPrefix("jdbc:odbc:");
		jaggSQL.setJdbcSuffix("JDP Tutorial");
		jaggSQL.setUID("");
		jaggSQL.setPWD("");
		jaggSQL.setCSTR("DSN=JDP Tutorial;UID=;PWD=;");
		jaggSQL.setMRW("1000");
		jaggSQL.setTOUT("60");

		recCount = jaggSQL.execSQL(SQL, results);

		if(recCount == -1) {
			user.u.setSqlMessage(jaggSQL,SQL);
			return;
		}

		//
		//  Initialise result arrays
		//
		tableContents.totalDataRows = jaggSQL.getRowCount();
		actualRows = jaggSQL.getRowCount()+20;
		tableContents.currentText = new String[columnCount][actualRows];

		tableContents.cellChanged = null;
		tableContents.rowChanged = null;
		tableContents.columnSelected = null;
		int keyCount = 3;
		tableContents.rowKey = new String[actualRows][keyCount];
		
		//
		//  Load key array and grid array
		//
		String tempText;
		for (int ix=0; ix<actualRows-20; ix++) {
			row = (String)results.elementAt(ix);
			if ((row != null) && (row.trim().compareTo("") != 0)) {
				stok = new StringTokenizer(row);
				for (int iy=0; iy<keyCount; iy++) {
					tableContents.rowKey[ix][iy] = stok.nextToken(sep).trim();
				}
				for (int iy=0; iy<columnCount; iy++) {
					tempText = stok.nextToken(sep).trim();
					tableContents.currentText[iy][ix] = tempText;
				}
			}
		}
		for (int ix=actualRows-20; ix<actualRows; ix++) {
			for (int iy=0; iy<keys.length; iy++) {
				tableContents.rowKey[ix][iy] = keys[iy];
			}
		}

		tableContents.newTable();

		//
		//  Clear status message
		//
		user.mainmsg.clearStatusMsg();
	}

	//
	//  Check each row that has changed and issue an update to the database
	//
	public void DetailGrid1UpdateRows(String[] keys) {

		JDPTextGrid tableContents = DetailGrid1;

		if (keys == null || keys.length < 0) {
			DetailGrid1LoadEmptyGrid();
			return;
		}

		int changedCount = 0;
		int insertedCount = 0;
		int cCount = 1;
		int iCount = 1;
		
		for (int ix=0; ix<tableContents.rowChanged.length; ix++) {
			if (tableContents.rowChanged[ix]) {
				if (ix >= tableContents.totalDataRows) {
					insertedCount++;
				} else {
					changedCount++;
				}
			}
		}
		for (int ix=0; ix<tableContents.rowChanged.length; ix++) {
			if (tableContents.rowChanged[ix]) {
				if (ix >= tableContents.totalDataRows) {
					user.mainmsg.setStatusMsg("Inserting row " + Integer.toString(iCount++) + " of " + Integer.toString(insertedCount) + "...", 0);
					DetailGrid1SaveData(ix,"I");
				} else {
					user.mainmsg.setStatusMsg("Updating row " + Integer.toString(cCount++) + " of " + Integer.toString(changedCount) + "...", 0);
					DetailGrid1SaveData(ix,"U");
				}
				tableContents.rowChanged[ix] = false;
			}
		}
		if (insertedCount > 0) {
			DetailGrid1LoadGrid(keys);
		}
	}

	//
	//  Delete any of the selected rows
	//
	public void DetailGrid1DeleteRows(String[] keys) {

		JDPTextGrid tableContents = DetailGrid1;

		if (keys == null || keys.length < 0) {
			DetailGrid1LoadEmptyGrid();
			return;
		}

		int deletedCount = 0;
		int cCount = 1;
		int iCount = 1;
		
		for (int ix=0; ix<tableContents.rowChanged.length; ix++) {
			if (tableContents.rowSelected[ix]) {
				deletedCount++;
			} 
		}
		for (int ix=0; ix<tableContents.rowChanged.length; ix++) {
			if (tableContents.rowSelected[ix]) {
				user.mainmsg.setStatusMsg("Deleting row " + Integer.toString(iCount++) + " of " + Integer.toString(deletedCount) + "...", 0);
				DetailGrid1SaveData(ix,"D");
			}
		}
		if (deletedCount > 0) {
			DetailGrid1LoadGrid(keys);
		}
	}

	//
	//  Save the selected item
	//
	boolean DetailGrid1SaveData(int tableRow, String action) {

		JDPTextGrid tableContents = DetailGrid1;
		int recCount = 0;
		Vector results = new Vector();
		String sep = jaggSQL.getSEP();
		String SQL = "";

		jaggSQL.setDSN("JDP Tutorial");
		jaggSQL.setJdbcDriver("sun.jdbc.odbc.JdbcOdbcDriver");
		jaggSQL.setJdbcPrefix("jdbc:odbc:");
		jaggSQL.setJdbcSuffix("JDP Tutorial");
		jaggSQL.setUID("");
		jaggSQL.setPWD("");
		jaggSQL.setCSTR("DSN=JDP Tutorial;UID=;PWD=;");
		jaggSQL.setMRW("1000");
		jaggSQL.setTOUT("60");

		if (action.equals("I")) {
			SQL = "INSERT INTO dbo_sales (stor_id, " +
					"ord_num, " +
					"ord_date, " +
					"qty, " +
					"payterms, " +
					"title_id) VALUES('" + user.u.replace(tableContents.currentText[0][tableRow],"'","''") + "', " +
					"'" + user.u.replace(tableContents.currentText[1][tableRow],"'","''") + "', " +
					"'" + user.u.replace(tableContents.currentText[2][tableRow],"'","''") + "', " +
					"" + tableContents.currentText[3][tableRow] + ", " +
					"'" + user.u.replace(tableContents.currentText[4][tableRow],"'","''") + "', " +
					"'" + user.u.replace(tableContents.currentText[5][tableRow],"'","''") + "')";
		} else {
			if (action.equals("D")) {
				SQL = "DELETE FROM dbo_sales" +
					" WHERE stor_id='" + tableContents.rowKey[tableRow][0] + "'"  +
					" AND ord_num='" + tableContents.rowKey[tableRow][1] + "'"  +
					" AND title_id='" + tableContents.rowKey[tableRow][2] + "'" ;
			} else {
				SQL = "UPDATE dbo_sales SET ord_date = '" + user.u.replace(tableContents.currentText[2][tableRow],"'","''") + "', " +
					"qty = " + tableContents.currentText[3][tableRow] + ", " +
					"payterms = '" + user.u.replace(tableContents.currentText[4][tableRow],"'","''") + "'" +
					" WHERE stor_id='" + tableContents.rowKey[tableRow][0] + "'"  +
					" AND ord_num='" + tableContents.rowKey[tableRow][1] + "'"  +
					" AND title_id='" + tableContents.rowKey[tableRow][2] + "'" ;
			}
		}

		recCount = jaggSQL.execSQL(SQL, results);

		if (user.DEBUG) System.out.println("saveData CNT: "+Integer.toString(recCount));

		if(recCount == -1) {
			user.u.setSqlMessage(jaggSQL,SQL);
			return false;
		}
		if(recCount == 1) {
			if (action.equals("I")) {
				user.mainmsg.setStatusMsg("Record successfully added.",3);
			} else 
			if (action.equals("D")) {
				user.mainmsg.setStatusMsg("Record successfully removed.",3);
			} else {
				user.mainmsg.setStatusMsg("Record successfully updated.",3);
			}
		} else {
			user.u.setSqlMessage(jaggSQL,SQL);
		}
		return true;

	}

	//
	//  Load the grid with the blank rows to allow data entry
	//
	public void DetailGrid1LoadEmptyGrid() {

		JDPTextGrid tableContents = DetailGrid1;
		int columnCount = 6;

		tableContents.currentText = new String[columnCount][50];
		tableContents.cellChanged = null;
		tableContents.rowChanged = null;
		tableContents.columnSelected = null;
		tableContents.rowKey = new String[50][1];
		tableContents.newTable();
		tableContents.totalDataRows = 0;
	}

	//
	//  Set up the parameters for this grid
	//
	void DetailGrid1SetGridSettings() {

		if (DetailGrid1 == null) {
			DetailGrid1 = new JDPTextGrid(user);
		} 
		JDPTextGrid tableContents = DetailGrid1;
		int columnCount = 6;

		tableContents.columnHeader = new String[columnCount];
		tableContents.columnHeaderStyle = new int[columnCount];
		tableContents.columnStyle = new int[columnCount];
		tableContents.columnHeaderColor = new Color[columnCount];
		tableContents.columnColor = new Color[columnCount];
		tableContents.columnBGColor = new Color[columnCount];
		tableContents.columnProtected = new boolean[columnCount];
		tableContents.columnWidth = new int[columnCount];
		tableContents.rightJustify = new boolean[columnCount];
		tableContents.rowHeader = null;
		tableContents.columnHeight = null;
		for (int ix=0; ix<columnCount; ix++) {
			tableContents.columnHeaderStyle[ix] = Font.BOLD;
			tableContents.columnStyle[ix] = Font.PLAIN;
			tableContents.columnHeaderColor[ix] = Color.black;
			tableContents.columnColor[ix] = Color.black;
			tableContents.columnBGColor[ix] = Color.white;
			tableContents.columnStyle[ix] = Font.PLAIN;
		}
		tableContents.columnWidth[0] = 46;
		tableContents.columnWidth[1] = 150;
		tableContents.columnWidth[2] = 126;
		tableContents.columnWidth[3] = 32;
		tableContents.columnWidth[4] = 98;
		tableContents.columnWidth[5] = 56;
		tableContents.rightJustify[3] = true;
		tableContents.columnHeader[0] = "Stor Id";
		tableContents.columnHeader[1] = "Ord Num";
		tableContents.columnHeader[2] = "Ord Date";
		tableContents.columnHeader[3] = "Qty";
		tableContents.columnHeader[4] = "Payterms";
		tableContents.columnHeader[5] = "Title Id";

		DetailGrid1LoadEmptyGrid();
		DetailGrid1LoadChoices();
	}

	//
	//  Load all of the Screen Choices
	//
	void DetailGrid1LoadChoices() {

		JDPTextGrid tableContents = DetailGrid1;
		int columnCount = 6;

		jaggSQL.setDSN("JDP Tutorial");
		jaggSQL.setJdbcDriver("sun.jdbc.odbc.JdbcOdbcDriver");
		jaggSQL.setJdbcPrefix("jdbc:odbc:");
		jaggSQL.setJdbcSuffix("JDP Tutorial");
		jaggSQL.setUID("");
		jaggSQL.setPWD("");
		jaggSQL.setCSTR("DSN=JDP Tutorial;UID=;PWD=;");
		jaggSQL.setMRW("1000");
		jaggSQL.setTOUT("60");

		tableContents.isPullDownCol = new boolean[columnCount];
		tableContents.pullDownList = new List[columnCount][1];
	}

	//
	//  Create and load the Result List Panel
	//
	public void ResultList1Main() {

		String ResultList1sf = "stor_id,ord_num,title_id";
		String[] ResultList1df = {"ord_num","title_id"};
		String ResultList1wc = "(1=1)";
		String[] ResultList1sct = {"Stor Id"};
		String[] ResultList1sc = {"stor_id"};
		jaggSQL.setDSN("JDP Tutorial");
		jaggSQL.setJdbcDriver("sun.jdbc.odbc.JdbcOdbcDriver");
		jaggSQL.setJdbcPrefix("jdbc:odbc:");
		jaggSQL.setJdbcSuffix("JDP Tutorial");
		jaggSQL.setUID("");
		jaggSQL.setPWD("");
		jaggSQL.setCSTR("DSN=JDP Tutorial;UID=;PWD=;");
		jaggSQL.setMRW("1000");
		jaggSQL.setTOUT("60");
		ResultList1 = new JDPSearchResults(user, targetPanel, true, jaggSQL, false, ResultList1sf, ResultList1df, ResultList1wc, ResultList1sct, ResultList1sc, ResultList1sc, "", true, "Total Entries:");
		int[] ResultList1icons = new int[8];
		ResultList1icons[0] = 3;
		ResultList1icons[1] = 5;
		ResultList1icons[2] = 2;
		ResultList1icons[3] = 8;
		ResultList1.setMinWidth(130);
		ResultList1.setIcons(ResultList1icons);
		ResultList1.setFromWhereClause(" FROM dbo_sales WHERE (1=1)");
		ResultList1.clearList("");
		ResultList1.loadList();
	}


}

