//--------------------------------------------------------------------
//                                                                    
//  Module:       LoadTree                                       
//  Description:  LoadTree
//                                                                    
//--------------------------------------------------------------------

import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import java.util.*;
import java.io.*;
import java.net.*;


public class LoadTree extends JDPClassLayout  {

	JDPUser user;
	JDPJagg jaggSQL;
	JDPPopupMessage popuppanel;
	JDPMaskEdit JDPMaskEditMain;
	String moduleParameter;
	//
	//  Declare screen components
	//
	Panel Main;
	JDPDragItem DragAndDrop1;
	Panel Panel1;
	JDPChiselFramePanel ChiselPanel1;
	JDPTreePicker TreeStructure1;
	JDPChiselFramePanel ChiselPanel2;
	JDPTreePicker TreeStructure2;

	public void InitClass(JDPUser user, Panel targetPanel, String moduleParameter) {

		this.user = user;
		this.moduleParameter = moduleParameter;
		//
		//  Set JAGG settings for this class
		//
		jaggSQL = new JDPJagg(user.jaggPath);

		setLayout(new BorderLayout());
		popuppanel = new JDPPopupMessage(user,this);
		add(popuppanel);
		JDPMaskEditMain = new JDPMaskEdit();

		CheckboxGroup cbGroup4 = new CheckboxGroup();
		Main = new Panel();
		DragAndDrop1 = new JDPDragItem(user.getJDPUser(), Main);
		Panel1 = new Panel();
		ChiselPanel1 = new JDPChiselFramePanel(user, "Drag a branch from this tree to the lower one");
		TreeStructure1 = new JDPTreePicker(user);
		TreeStructure1.setRoot("My Tree Structure", true);
		ChiselPanel2 = new JDPChiselFramePanel(user, "Drop the branch on this tree");
		TreeStructure2 = new JDPTreePicker(user);
		TreeStructure2.setRoot("My Other Tree Structure", true);

		Main.setLayout(new BorderLayout());
		add("Center", Main);
		Main.add("West", DragAndDrop1);
		Main.add("Center", Panel1);
		Panel1.setLayout(new GridLayout(2,2));
		Panel1.add(ChiselPanel1);
		ChiselPanel1.add("Center", TreeStructure1);
		Panel1.add(ChiselPanel2);
		ChiselPanel2.add("Center", TreeStructure2);



		//
		//  Initialise Components
		//
		InitComponents();
		//
		//  Add the handle to this panel to the global vector so other panels can
		//  access this one
		//
		user.gParm.addElement(this);
	}

	//
	//  Handle screen events
	//
	public boolean handleEvent(Event e) {

		switch (e.id) {
		case Event.ACTION_EVENT:
			if (e.target.equals(DragAndDrop1)) {
				JDPTreeBranch[] dragBranch = DragAndDrop1.getDraggedBranch(TreeStructure1);
				JDPTreeBranch[] dropBranch = DragAndDrop1.getDroppedBranch(TreeStructure2);
				if (dragBranch != null && dropBranch != null) {
					JDPTreeBranch thisBranch = dropBranch[dropBranch.length-1];
					String name = dragBranch[dragBranch.length-1].name;
					int icon = dragBranch[dragBranch.length-1].icon;
					TreeStructure2.addBranch(thisBranch, name, icon, false, null, null, false);
					thisBranch.expanded = true;
					TreeStructure1.reDraw();
				}
				return true;
			}
			return false;

		case Event.MOUSE_DRAG:
			if (e.target.equals(Panel1)) {
				DragAndDrop1.postEvent(e);
				return true;
			}
			return false;

		case Event.MOUSE_MOVE:
		case Event.MOUSE_ENTER:
		case Event.MOUSE_EXIT:
			popuppanel.postEvent(e);
			return false;

		default:
			return false;

		}
	}


	//
	//  Initialise other components by calling their methods
	//
	public void InitComponents() {

		int[] icons = {JDPTreePicker.COMPUTER,JDPTreePicker.PERSON,JDPTreePicker.FOLDER,JDPTreePicker.DOCUMENT};
		String[] entry = {"",null,null,null};
		boolean[] expanded = {true,true,true,true,true};
		TreeStructure1.setIcons(icons);
		TreeStructure1.setExpanded(expanded);
		TreeStructure1.setDragPanel(DragAndDrop1);
		Object[] dropKeys = {"TreeItem","TreeItem"};
		String[] dropMessages = new String[2];
		dropMessages[1] = "Drop here";
		TreeStructure1.setDropKeys(dropKeys);
		TreeStructure1.setDragAndDrop(null);
		TreeStructure1.setDropMessages(null);
		TreeStructure1.setRoot("Employees",true);

		//
		//  Add branches to the tree using the addBranch method
		//
		JDPTreeBranch lastBranch = TreeStructure1.treeRoot;
		TreeStructure1.addBranch(lastBranch,"Branch1",JDPTreePicker.FOLDER);
		lastBranch = TreeStructure1.getLastAddedBranch();
		TreeStructure1.addBranch(lastBranch,"Leaf1",JDPTreePicker.DOCUMENT);
		lastBranch = TreeStructure1.getBranch("Branch1");
		TreeStructure1.addBranch(lastBranch,"Leaf2",JDPTreePicker.DOCUMENT);
		lastBranch = TreeStructure1.treeRoot;
		TreeStructure1.addBranch(lastBranch,"Branch2",JDPTreePicker.FOLDER);

		TreeStructure1.reDraw();		

		int[] icons2 = {JDPTreePicker.FOLDER,JDPTreePicker.DOCUMENT};
		String[] entry2 = {"",null};
		boolean[] expanded2 = {true,true,true};
		TreeStructure2.setIcons(icons2);
		TreeStructure2.setExpanded(expanded2);
		TreeStructure2.setDragPanel(DragAndDrop1);
		Object[] dropKeys2 = {null,"TreeItem"};
		String[] dropMessages2 = new String[2];
		dropMessages2[1] = "Drop here";
		TreeStructure2.setDropKeys(dropKeys2);
		TreeStructure2.setDragAndDrop(null);
		TreeStructure2.setDropMessages(dropMessages2);
		TreeStructure2.setRoot("Positions",true);

		TreeStructure2.reDraw();		
	}

}

