//--------------------------------------------------------------------
//                                                                    
//  Module:       SalesChartByStore                                       
//  Description:  SalesChartByStore
//                                                                    
//--------------------------------------------------------------------

import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import java.util.*;
import java.io.*;
import java.net.*;


public class SalesChartByStore extends JDPClassLayout  {

	JDPUser user;
	JDPJagg jaggSQL;
	JDPPopupMessage popuppanel;
	JDPMaskEdit JDPMaskEditMain;
	String moduleParameter;
	//
	//  Declare screen components
	//
	Panel Main;
	JDPChiselFramePanel ChiselPanel1;
	Panel Chart1;
	Panel Panel1;
	JDPWhereClause Chart1SP1;
	JDPChart Chart1CL1;

	public void InitClass(JDPUser user, Panel targetPanel, String moduleParameter) {

		this.user = user;
		this.moduleParameter = moduleParameter;
		this.targetPanel = targetPanel;
		//
		//  Set JAGG settings for this class
		//
		jaggSQL = new JDPJagg(user.jaggPath);

		setLayout(new BorderLayout());
		popuppanel = new JDPPopupMessage(user,this);
		add(popuppanel);
		JDPMaskEditMain = new JDPMaskEdit();

		Main = new Panel();
		ChiselPanel1 = new JDPChiselFramePanel(user, "Sales Chart by Store");
		Chart1 = new Panel();
		Panel1 = new Panel();
				
		Main.setLayout(new BorderLayout());
		add("Center", Main);
		Main.add("Center", ChiselPanel1);
		ChiselPanel1.add("Center", Chart1);
		Chart1.setLayout(new BorderLayout());
		Chart1Main();
		Chart1.add("Center", Panel1);
		Panel1.setLayout(new BorderLayout());
		Panel1.add("North", Chart1SP1);
		Panel1.add("Center", Chart1CL1);

		Chart1SP1.setHorizontalLayout(true);


		//
		//  Initialise Components
		//
		InitComponents();
		//
		//  Add the handle to this panel to the global vector so other panels can
		//  access this one
		//
		user.gParm.addElement(this);
	}

	//
	//  Handle screen events
	//
	public boolean handleEvent(Event e) {

		switch (e.id) {
		case Event.ACTION_EVENT:
			if (e.target.equals(Chart1SP1)) {
				Chart1LoadDataFromWhereClause(Chart1SP1.getFromWhereClause());
				return true;
			}
			return false;

		case Event.MOUSE_MOVE:
		case Event.MOUSE_ENTER:
		case Event.MOUSE_EXIT:
			popuppanel.postEvent(e);
			return false;

		default:
			return false;

		}
	}


	//
	//  Initialise other components by calling their methods
	//
	public void InitComponents() {

		jaggSQL.setKeepConnectionOpen(false);

	}

	//
	//  Main initialization method
	//
	public void Chart1Main() {

		Chart1SetChartParms();
		Chart1LoadData(null);
		Chart1WhereClauseMain();
		Chart1SearchResultsMain();

	}

	//
	//  Load the chart with the specified parameters and selected data
	//
	public void Chart1LoadDataFromWhereClause(String whereClause) {

		int fPos = whereClause.indexOf("WHERE ");
		whereClause = " AND" + whereClause.substring(fPos+5);
		String[] keys = new String[0];

		Chart1LoadDataMain(keys, whereClause);
	}

	//
	//  Load the chart with the specified parameters and selected data
	//
	public void Chart1LoadData(String[] keys) {

		Chart1LoadDataMain(keys, null);
	}

	//
	//  Load the chart with the specified parameters and selected data
	//
	void Chart1LoadDataMain(String[] keys, String whereClauseParm) {

		JDPChartParms p = Chart1CL1.p;

		StringTokenizer stok;
		int recCount = 0;
		Vector results = new Vector();
		String sep = jaggSQL.getSEP();
		int actualRows = 0;
		String row;
		String whereClause = "(1=1)";

		int groupCount = 1;
		int seriesCount = 0;

		if (keys != null && keys.length > 0 && keys[0] != null) whereClause += " AND stor_id='" + keys[0]+ "'" ;
		if (whereClauseParm != null) {
			whereClause += whereClauseParm;
		}
		String SQL = "SELECT LEFT(format(ord_date, 'yy/mm/dd'),5),SUM(qty) FROM dbo_sales  WHERE " + whereClause + " GROUP BY LEFT(format(ord_date, 'yy/mm/dd'),5) ORDER BY SUM(qty) DESC";


		user.mainmsg.setStatusMsg(JDPLang.get("Message0"), 0);

		jaggSQL.setDSN("JDP Tutorial");
		jaggSQL.setUID("");
		jaggSQL.setPWD("");
		jaggSQL.setMRW("1000");
		jaggSQL.setTOUT("60");

		recCount = jaggSQL.execSQL(SQL, results);

		if(recCount == -1) {
			user.u.setSqlMessage(jaggSQL,SQL);
			return;
		}
		if(recCount == 0) {
			user.mainmsg.setStatusMsg(JDPLang.get("Message10"),10);
			Chart1CL1.hide();
			return;
		}
		Chart1CL1.show();

		//
		//  Initialise result arrays
		//
		int columnCount = jaggSQL.getColumnCount();
		actualRows = jaggSQL.getRowCount();

		if (seriesCount <= 0) {
			p.chartData = new float[columnCount-groupCount][actualRows];
			p.xaxisLabel = new String[actualRows];
			p.piechartData = new float[actualRows];
			p.pieSplitSegment = new boolean[actualRows];
			p.pieLabel = new String[actualRows];
			if (p.chartType == JDPChart.PIE ||
				p.chartType == JDPChart.GANTT) {
				p.elementColor = new Color[actualRows];
				p.elementBorderColor = new Color[actualRows];
 				p.elementLegend = new String[actualRows];
			}
			for (int ix=0; ix<actualRows; ix++) {
				row = (String)results.elementAt(ix);
				stok = new StringTokenizer(row,sep);
				p.xaxisLabel[ix] = "";
				if (groupCount > 0) p.xaxisLabel[ix] = stok.nextToken().trim();
				for (int iz=0; iz<columnCount-groupCount; iz++) {
					if (p.chartType == JDPChart.GANTT) {
						String date = stok.nextToken();
						Date thisDate = new Date(Integer.parseInt(date.substring(2,4)),Integer.parseInt(date.substring(5,7))-1,Integer.parseInt(date.substring(8,10)));
						long val = thisDate.getTime()/(86400000);
						p.chartData[iz][ix] = (float)val;
					} else {
						p.chartData[iz][ix] = Float.valueOf(stok.nextToken().trim()).floatValue();
					}
				}
				p.pieLabel[ix] = p.xaxisLabel[ix];
				p.piechartData[ix] = p.chartData[0][ix];
				if (p.chartType == JDPChart.PIE ||
					p.chartType == JDPChart.GANTT) {
					p.elementColor[ix] = JDPUtils.colorList[ix%12];
					p.elementBorderColor[ix] = Color.black;
 					p.elementLegend[ix] = p.pieLabel[ix];
				}
			}
		} else {
			float[][] tempchartData = new float[1000][actualRows];
			p.xaxisLabel = new String[actualRows];
			Vector group = new Vector();
			if (groupCount == 0) group.addElement("");
			Vector series = new Vector();
			for (int ix=0; ix<actualRows; ix++) {
				row = (String)results.elementAt(ix);
				stok = new StringTokenizer(row,sep);
				p.xaxisLabel[ix] = "";
				int groupIndex = 0;
				if (groupCount > 0) {
					String groupValue = stok.nextToken().trim();
					groupIndex = group.indexOf(groupValue);
					if (groupIndex < 0) {
						group.addElement(groupValue);
						groupIndex = group.indexOf(groupValue);
						p.xaxisLabel[groupIndex] = groupValue;
					}
				}
				String seriesValue = stok.nextToken().trim();
				int seriesIndex = series.indexOf(seriesValue);
				if (seriesIndex < 0) {
					series.addElement(seriesValue);
					seriesIndex = series.indexOf(seriesValue);
				}
				tempchartData[seriesIndex][groupIndex] = Float.valueOf(stok.nextToken().trim()).floatValue();
			}

			int numbars = series.size();
			p.chartData = new float[numbars][group.size()];
			for (int ix=0; ix<numbars; ix++) {
				for (int iy=0; iy<group.size(); iy++) {
					p.chartData[ix][iy] = tempchartData[ix][iy];
				}
			}
			p.elementColor = new Color[numbars];
			p.elementBorderColor = new Color[numbars];
 			p.elementLegend = new String[numbars];
			for (int ix=0; ix<numbars; ix++) {
				p.elementColor[ix] = JDPUtils.colorList[ix%12];
				p.elementBorderColor[ix] = Color.black;
 				p.elementLegend[ix] = (String)series.elementAt(ix);
			}
		}
		Chart1CL1.calculateScaling();
		Chart1CL1.repaint();

		user.mainmsg.clearStatusMsg();
	}

	//
	//  Load the parameters for the selected chart
	//
	public void Chart1SetChartParms() {

		JDPChartParms p;
		if (Chart1CL1 == null) {
			p = new JDPChartParms();
			Chart1CL1 = new JDPChart(user, p);
		} else {
			p = Chart1CL1.p;
		}

		p.chartType = 5;
		p.autoscale = true;
		p.autozoom = true;

		p.chartTitle = "Sales Chart by Store";
		p.chartTitleFont = user.boldFont.getName();
		p.chartTitleColor = user.u._cvtcolor("Black");

		p.xaxisTitle = "";
		p.xaxisTitleFont = user.boldFont.getName();
		p.xaxisTitleColor = user.u._cvtcolor("Black");

		p.yaxisLabel = new String[10];

		p.elementLegendFont = user.boldFont.getName();

		p.xaxisLabelColor = user.u._cvtcolor("Black");
		p.yaxisLabelColor = user.u._cvtcolor("Black");
		p.chartFrameColor = user.u._cvtcolor("Black");

		p.elementLegend = new String[1];
		p.elementColor = new Color[1];
		p.elementBorderColor = new Color[1];
		p.elementLegend[0] = "Qty";
		p.elementColor[0] = user.u._cvtcolor("Magenta");
		p.elementBorderColor[0] = user.u._cvtcolor("Black");

		p.gridLineSetting = JDPChart.HORIZONTAL + JDPChart.VERTICAL + JDPChart.FOREGROUND + JDPChart.BACKGROUND;
		p.gridColor = user.u._cvtcolor("Gray");

		p.maxPlotValue = 100;
		p.minPlotValue = 0;

		if ((p.chartType == JDPChart.COLUMN) || (p.chartType == JDPChart.BAR) ||
			(p.chartType == JDPChart.AREA)) {
			p.autozoom = false;
		}

		p.pieLabel = p.elementLegend;
		p.pieLabelColor = p.xaxisTitleColor;

	}

	//
	//  Create and load the Search Panel
	//
	public void Chart1WhereClauseMain() {

		String[] Chart1cf = new String[1];
		String[] Chart1acf = new String[1];
		Vector Chart1mu = new Vector();
		Vector Chart1amu = new Vector();
		Chart1cf[0] = "Store Name";
		Chart1acf[0] = "stor_id";
		Chart1mu.addElement(new Vector());
		Chart1amu.addElement(new Vector());
		jaggSQL.setDSN("JDP Tutorial");
		jaggSQL.setUID("");
		jaggSQL.setPWD("");
		jaggSQL.setMRW("1000");
		jaggSQL.setTOUT("60");
		JDPLoadChoice lc = new JDPLoadChoice(user,jaggSQL,null,"","","","",-1);
		lc.loadChoice((Vector)Chart1mu.elementAt(0), "stor_name" ,"stor_id" ,"dbo_stores" ,"(1=1)" ,(Vector)Chart1amu.elementAt(0),12);
		int[] Chart1cl = new int[1];
		boolean[] Chart1cis = new boolean[1];
		Chart1cl[0] = 0;
		Chart1cis[0] = true;
		Chart1SP1 = new JDPWhereClause(user, targetPanel, "", true, "", Chart1cf, Chart1acf, Chart1mu, Chart1amu, null, null, Chart1cl, Chart1cis, "FROM dbo_sales WHERE (1=1)");
		Chart1SP1.setDSNType("ACCESS");
		Chart1SP1.setDataType(0,12);
	}

	//
	//  Create and load the Result List Panel
	//
	public void Chart1SearchResultsMain() {

	}


}

