//--------------------------------------------------------------------
//                                                                    
//  Module:       NextAvailableNum                                       
//  Description:  NextAvailableNum
//                                                                    
//--------------------------------------------------------------------

import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import java.util.*;
import java.io.*;
import java.net.*;


public class NextAvailableNum extends JDPClassLayout  {

	JDPUser user;
	JDPJagg jaggSQL;
	JDPPopupMessage popuppanel;
	JDPMaskEdit JDPMaskEditMain;
	String moduleParameter;
	//
	//  Declare screen components
	//
	Panel Main;
	JDPScrollPanel ScrollPanel1;
	Button Button1;
	TextField TextField1;
	Label Label1;
	JDPRMIConnection RMIConnection1;

	public void InitClass(JDPUser user, Panel targetPanel, String moduleParameter) {

		this.user = user;
		this.moduleParameter = moduleParameter;
		this.targetPanel = targetPanel;
		//
		//  Set JAGG settings for this class
		//
		jaggSQL = new JDPJagg(user.jaggPath);

		setLayout(new BorderLayout());
		popuppanel = new JDPPopupMessage(user,this);
		add(popuppanel);
		JDPMaskEditMain = new JDPMaskEdit();

		Main = new Panel();
		ScrollPanel1 = new JDPScrollPanel();
		Button1 = new Button("Press to get the next available number");
		TextField1 = new TextField("", 20);
		Label1 = new Label("This demo uses JDesignerPro's lightweight RMI to get a number from the NextAvailableNumber Entity on the server", Label.LEFT);
		RMIConnection1 = new JDPRMIConnection(user);

		Main.setLayout(new BorderLayout());
		add("Center", Main);
		Main.add("Center", ScrollPanel1);
		ScrollPanel1.add("Left", Button1);
		ScrollPanel1.add("Left", TextField1);
		Main.add("North", Label1);



		//
		//  Add the handle to this panel to the global vector so other panels can
		//  access this one
		//
		user.gParm.addElement(this);
		//
		//  Initialise Components
		//
		InitComponents();
	}

	//
	//  Handle screen events
	//
	public boolean handleEvent(Event e) {

		switch (e.id) {
		case Event.ACTION_EVENT:
			if (e.target.equals(Button1)) {
				// The first parameter is the name of the job we are looking for
				// on the server. The second parameter is the name of the method
				// we want to call. Note that if this method required parameters
				//  we would need to use the other invokeByJobName method.
				int[] jobs = RMIConnection1.getJobsForName("NextAvailableNumber");
				if (jobs.length == 0) {
					//
					//  Start job on server
					//
					startJob();
				}
				
				jobs = RMIConnection1.getJobsForName("NextAvailableNumber");
				if (jobs.length > 0) {
					Integer secondsWait = (Integer)RMIConnection1.invokeByJobNumber(jobs[0], "getNextAvailableNumber");
					if (secondsWait != null) {
						TextField1.setText(secondsWait.toString());
					} else {
						user.mainmsg.setStatusMsg("Could not get next available number. Check that NextAvailableNumber job is running on server",15);
					}
				} else {
					user.mainmsg.setStatusMsg("Could not get next available number. Check that NextAvailableNumber job is running on server",15);
				}	
				return true;
			}
			return false;

		case Event.MOUSE_MOVE:
		case Event.MOUSE_ENTER:
		case Event.MOUSE_EXIT:
			popuppanel.postEvent(e);
			return false;

		default:
			return false;

		}
	}


	//
	//  Initialise other components by calling their methods
	//
	public void InitComponents() {

		jaggSQL.setKeepConnectionOpen(false);

	}

	//
	//  Start the next available number job on the server
	//
	public void startJob() {

		/**
		 * Submit a job to run on the server.
		 * @param jobQueue the queue to which the job is submitted.
		 * @param jobName the name to give this job.
		 * @param objectType the type of object to run (C-Java Class, A-Application, J-Job Stream).
		 * @param objectName the name of the class, application or job stream.
		 * @param objectConstructor the constructor to use for creating the Java class (eg "(JDPSubsystemMgr,JDPJob)"),
		 * @param objectParameters the parameters for this Java class or Application.
		 * @param jobExecutionPriority a priority in the range 1-10. 5 is default.
		 * @param jobQueuePriority a priority in the range 1-10. 5 is default.
		 * @param jobHeld true if job should be held on the job queue.
		 * @param notifyUser the userid of the user to notify upon completion (-1 for no notification).
		 * @param notifyVia notify via (E-Email, P-Pager, B-Both).
		 * @param nofifyOn notify on (S-Success, F-Failure, B-Both).
		 * @param logEvent log event on (N-No logging, S-Success, F-Failure, B-Both).
		 * @return either null if the job was submitted or a message telling why it was not submitted.
		 */

		String result = RMIConnection1.submitJob("QIMMED", "NextAvailableNumber", "C", "NextAvailableNumberEntity", "(JDPSubsystemMgr,JDPJob)", 
				"JDPSubsystemMgr,JDPJob", 5, 5, false, -1, "", "", "B");
		if (result == null) {
			user.mainmsg.setStatusMsg("Job submission failed.",10);
		} else 
		if (result.startsWith("Jobnumber:")) {
			user.mainmsg.setStatusMsg("NextAvailableNumber job submitted to QIMMED.",10);
		} else {
			user.mainmsg.setStatusMsg(result,20);
		}
		try {
			//	
			//  Wait a few seconds for job to start
			//
			Thread.sleep(3000);
		} catch (Exception ex) {
		}		

	}


}

