import java.io.*;
import java.net.*;
import java.util.*;


/**
 * Class to represent a job running on the server that stays running
 * to handle requests from clients or other running jobs.
 * @lastModified Wed Jul 01 14:56:41 PDT 1998
 */
public class NextAvailableNumberEntity {

	/*
	 * Jagg instance for database access.
	 */
	JDPJagg jaggSQL;
	/*
	 * Handle to the subsystem manager of the server.
	 */
	JDPSubsystemMgr manager;
	int nextAvailableNumber = 0;
	/*
	 * Handle to the job that this class is running in.
	 */
	JDPJob thisJob;

	/**
	 * Creates a new module that runs on the server and can be accessed 
	 * by other modules or by remote clients.
	 * @param manager the handle to the subsystem manager.
	 * @param thisJob the handle to the job in which this class runs.
	 */
	public NextAvailableNumberEntity(JDPSubsystemMgr manager, JDPJob thisJob) {

		this.manager = manager;
		this.thisJob = thisJob;
		thisJob.setInstance(this);

		thisJob.appendJobLog("Job started on " + (new Date()).toString());

		//
		//  Stay running while the server remains running or until
		//  manually terminated.
		//  
		while (!manager.shutdownRequested &&
			nextAvailableNumber < 20) {
			try {
				//
				// Insert repetitive processing here if required
				//

				//
				//  Wait 10 seconds until the next repetitve processing
				//  needs to be done
				//
				Thread.sleep(10000);
			} catch (Exception e) {
			}
		}
		
		thisJob.appendJobLog("Next available number reached " + Integer.toString(nextAvailableNumber));
		thisJob.appendJobLog("Job completed on " + (new Date()).toString());

	}



	/**
	 * Get the value of nextAvailableNumber.
	 * @return nextAvailableNumber.
	 */
	public int getNextAvailableNumber() {

		return nextAvailableNumber++;

	}


	/**
	 * Set the new value of nextAvailableNumber.
	 * @param nextAvailableNumber
	 */
	public void setNextAvailableNumber(int nextAvailableNumber) {

		this.nextAvailableNumber = nextAvailableNumber;

	}


}
