//--------------------------------------------------------------------
//                                                                    
//  Module:       SubmitServerJob                                       
//  Description:  SubmitServerJob
//                                                                    
//--------------------------------------------------------------------

import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import java.util.*;
import java.io.*;
import java.net.*;


public class SubmitServerJob extends JDPClassLayout  {

	JDPUser user;
	JDPJagg jaggSQL;
	JDPPopupMessage popuppanel;
	JDPMaskEdit JDPMaskEditMain;
	String moduleParameter;
	//
	//  Declare screen components
	//
	Panel Main;
	JDPScrollPanel ScrollPanel1;
	Button Button1;
	Label Label1;
	JDPRMIConnection RMIConnection1;

	public void InitClass(JDPUser user, Panel targetPanel, String moduleParameter) {

		this.user = user;
		this.moduleParameter = moduleParameter;
		this.targetPanel = targetPanel;
		//
		//  Set JAGG settings for this class
		//
		jaggSQL = new JDPJagg(user.jaggPath);

		setLayout(new BorderLayout());
		popuppanel = new JDPPopupMessage(user,this);
		add(popuppanel);
		JDPMaskEditMain = new JDPMaskEdit();

		Main = new Panel();
		ScrollPanel1 = new JDPScrollPanel();
		Button1 = new Button("Press to submit test job on Server");
		Label1 = new Label("This demo uses JDesignerPro's lightweight RMI to submit a job on the server", Label.LEFT);
		RMIConnection1 = new JDPRMIConnection(user);

		Main.setLayout(new BorderLayout());
		add("Center", Main);
		Main.add("Center", ScrollPanel1);
		ScrollPanel1.add("Left", Button1);
		Main.add("North", Label1);



		//
		//  Add the handle to this panel to the global vector so other panels can
		//  access this one
		//
		user.gParm.addElement(this);
		//
		//  Initialise Components
		//
		InitComponents();
	}

	//
	//  Handle screen events
	//
	public boolean handleEvent(Event e) {

		switch (e.id) {
		case Event.ACTION_EVENT:
			if (e.target.equals(Button1)) {
				/**
				 * Submit a job to run on the server.
				 * @param jobQueue the queue to which the job is submitted.
				 * @param jobName the name to give this job.
				 * @param objectType the type of object to run (C-Java Class, A-Application, J-Job Stream).
				 * @param objectName the name of the class, application or job stream.
				 * @param objectConstructor the constructor to use for creating the Java class (eg "(JDPSubsystemMgr,JDPJob)"),
				 * @param objectParameters the parameters for this Java class or Application.
				 * @param jobExecutionPriority a priority in the range 1-10. 5 is default.
				 * @param jobQueuePriority a priority in the range 1-10. 5 is default.
				 * @param jobHeld true if job should be held on the job queue.
				 * @param notifyUser the userid of the user to notify upon completion (-1 for no notification).
				 * @param notifyVia notify via (E-Email, P-Pager, B-Both).
				 * @param nofifyOn notify on (S-Success, F-Failure, B-Both).
				 * @param logEvent log event on (N-No logging, S-Success, F-Failure, B-Both).
				 * @return either "Jobnumber:nnn" if the job was submitted or a message telling why it was not submitted.
				 */
				
				String result = RMIConnection1.submitJob("QBATCH", "Test Job", "C", "JDPChoice", "()", 
						"", 5, 5, true, -1, "", "", "B");
				if (result == null) {
					user.mainmsg.setStatusMsg("Job submission failed.",10);
				} else 
				if (result.startsWith("Jobnumber:")) {	
					user.mainmsg.setStatusMsg("Job submitted and held on QBATCH. Go to Job Queues in Server Manager to release job.",30);
				} else {
					user.mainmsg.setStatusMsg(result,15);
				}
				return true;
			}
			return false;

		case Event.MOUSE_MOVE:
		case Event.MOUSE_ENTER:
		case Event.MOUSE_EXIT:
			popuppanel.postEvent(e);
			return false;

		default:
			return false;

		}
	}


	//
	//  Initialise other components by calling their methods
	//
	public void InitComponents() {

		jaggSQL.setKeepConnectionOpen(false);

	}


}

