import java.io.*;
import java.net.*;
import java.util.*;


/**
 * Class to represent a job running on the server that stays running
 * to handle requests from clients or other running jobs.
 * @lastModified Tue Aug 25 14:05:59 PDT 1998
 */
public class UserSecurityCheck {

	/*
	 * Jagg instance for database access.
	 */
	JDPJagg jaggSQL;
	/*
	 * Handle to the subsystem manager of the server.
	 */
	JDPSubsystemMgr manager;
	/*
	 * Handle to the job that this class is running in.
	 */
	JDPJob thisJob;

	/**
	 * Creates a new module that runs on the server and can be accessed 
	 * by other modules or by remote clients.
	 * @param manager the handle to the subsystem manager.
	 * @param thisJob the handle to the job in which this class runs.
	 */
	public UserSecurityCheck(JDPSubsystemMgr manager, JDPJob thisJob) {

		this.manager = manager;
		this.thisJob = thisJob;
		thisJob.setInstance(this);

		thisJob.appendJobLog("Job started on " + (new Date()).toString());

		//
		//  Stay running while the server remains running or until
		//  manually terminated.
		//  
		while (!manager.shutdownRequested) {
			try {
				//
				// Insert repetitive processing here if required
				//

				//
				//  Wait 60 seconds until the next repetitve processing
				//  needs to be done
				//
				Thread.sleep(60000);
			} catch (Exception e) {
			}
		}
				
		thisJob.appendJobLog("Job completed on " + (new Date()).toString());

	}



	/**
	 * Called from client to validate a user.
	 * @param username the username of the user to validate.
	 * @param password the password of the user to validate.
	 */
	public boolean validateUser(String username, String password) {
		
		if (username.equals("Michael") && password.equals("Michael")) {
			thisJob.appendJobLog("Successfully validated: " + username);
			return true;
		}
		thisJob.appendJobLog("Validation failed for: " + username);
		return false;
	}

}
