//--------------------------------------------------------------------
//                                                                    
//  Module:       ReceiveServerPush                                       
//  Description:  ReceiveServerPush
//                                                                    
//--------------------------------------------------------------------

import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import java.util.*;
import java.io.*;
import java.net.*;


public class ReceiveServerPush extends JDPClassLayout  {

	JDPUser user;
	JDPJagg jaggSQL;
	JDPPopupMessage popuppanel;
	JDPMaskEdit JDPMaskEditMain;
	String moduleParameter;
	//
	//  Declare screen components
	//
	Panel Main;
	Label Label1;
	Panel Panel1;
	Panel Panel3;
	JDPScrollPanel ScrollPanel1;
	JDPButton JDPButton2;
	JDPScrollPanel ScrollPanel2;
	Label Label3;
	TextField dataReceived;
	JDPServerListener MessageReceiver1;
	JDPRMIConnection RMIConnection1;

	public void InitClass(JDPUser user, Panel targetPanel, String moduleParameter) {

		this.user = user;
		this.moduleParameter = moduleParameter;
		this.targetPanel = targetPanel;
		//
		//  Set JAGG settings for this class
		//
		jaggSQL = new JDPJagg(user.jaggPath);

		setLayout(new BorderLayout());
		popuppanel = new JDPPopupMessage(user,this);
		add(popuppanel);
		JDPMaskEditMain = new JDPMaskEdit();

		Main = new Panel();
		Label1 = new Label("This example demostrates using server push to send a message to a JDP client", Label.LEFT);
		Panel1 = new Panel();
		Panel3 = new Panel();
		ScrollPanel1 = new JDPScrollPanel();
		JDPButton2 = new JDPButton("Press to register to receive requests of type 'ServerPushTest'", JDPButton.getAlignmentValue("Center"));
		ScrollPanel2 = new JDPScrollPanel();
		Label3 = new Label("Data received from ServerPushEntity:", Label.LEFT);
		dataReceived = new TextField("", 26);
		MessageReceiver1 = user.serverListener;
		RMIConnection1 = new JDPRMIConnection(user);

		Main.setLayout(new BorderLayout());
		add("Center", Main);
		Main.add("North", Label1);
		Main.add("Center", Panel1);
		Panel1.setLayout(new BorderLayout());
		Panel1.add("Center", Panel3);
		Panel3.setLayout(new BorderLayout());
		Panel3.add("North", ScrollPanel1);
		ScrollPanel1.add("Left", JDPButton2);
		Panel3.add("Center", ScrollPanel2);
		ScrollPanel2.add("Left", Label3);
		ScrollPanel2.add("Right", dataReceived);



		//
		//  Add the handle to this panel to the global vector so other panels can
		//  access this one
		//
		user.gParm.addElement(this);
		//
		//  Initialise Components
		//
		InitComponents();
	}

	//
	//  Handle screen events
	//
	public boolean handleEvent(Event e) {

		switch (e.id) {
		case Event.ACTION_EVENT:
			if (e.target.equals(JDPButton2)) {
				startJob();
				MessageReceiver1.registerForRequest("ServerPushTest", this);
				user.mainmsg.setStatusMsg("Registration complete", 10);
				return true;
			}
			if (e.target.equals(MessageReceiver1)) {
				if (e.arg instanceof String) {
					String data = (String)e.arg;
					if (data.startsWith("ServerPushTest")) {
						data = data.substring(data.indexOf("|")+1);
						dataReceived.setText(data);
					}
				}
				return true;
			}
			return false;

		case Event.MOUSE_MOVE:
		case Event.MOUSE_ENTER:
		case Event.MOUSE_EXIT:
			popuppanel.postEvent(e);
			return false;

		default:
			return false;

		}
	}


	//
	//  Initialise other components by calling their methods
	//
	public void InitComponents() {

		jaggSQL.setKeepConnectionOpen(false);

	}

	//
	//  Start the next available number job on the server
	//
	public void startJob() {

		//
		//  If Server Push job is already then exit otherwise start it
		//
		int[] jobs = RMIConnection1.getJobsForName("ServerPushEntity");
		if (jobs.length > 0) {
			return;
		}

		/**
		 * Submit a job to run on the server.
		 * @param jobQueue the queue to which the job is submitted.
		 * @param jobName the name to give this job.
		 * @param objectType the type of object to run (C-Java Class, A-Application, J-Job Stream).
		 * @param objectName the name of the class, application or job stream.
		 * @param objectConstructor the constructor to use for creating the Java class (eg "(JDPSubsystemMgr,JDPJob)"),
		 * @param objectParameters the parameters for this Java class or Application.
		 * @param jobExecutionPriority a priority in the range 1-10. 5 is default.
		 * @param jobQueuePriority a priority in the range 1-10. 5 is default.
		 * @param jobHeld true if job should be held on the job queue.
		 * @param notifyUser the userid of the user to notify upon completion (-1 for no notification).
		 * @param notifyVia notify via (E-Email, P-Pager, B-Both).
		 * @param nofifyOn notify on (S-Success, F-Failure, B-Both).
		 * @param logEvent log event on (N-No logging, S-Success, F-Failure, B-Both).
		 * @return either "Jobnumber:nnn"  if the job was submitted or a message telling why it was not submitted.
		 */

		String result = RMIConnection1.submitJob("QIMMED", "ServerPushEntity", "C", "ServerPushEntity", "(JDPSubsystemMgr,JDPJob)", 
				"JDPSubsystemMgr,JDPJob", 5, 5, false, -1, "", "", "B");
		if (result == null) {
			user.mainmsg.setStatusMsg("Job submission failed.",10);
		} else 
		if (result.startsWith("Jobnumber:")) {
			user.mainmsg.setStatusMsg("ServerPushEntity job submitted to QIMMED.",10);
		} else {
			user.mainmsg.setStatusMsg(result,20);
		}
		try {
			//	
			//  Wait a few seconds for job to start
			//
			Thread.sleep(3000);
		} catch (Exception ex) {
		}		

	}


}

