import java.io.*;
import java.net.*;
import java.util.*;
import java.awt.Event;

/**
 * Class to send messages to clients that have registered to receive
 * them.
 * @lastModified Mon Aug 31 20:31:40 PDT 1998
 */
public class ServerPushEntity {

	JDPServerSender MessageSender1;
	/*
	 * Jagg instance for database access.
	 */
	JDPJagg jaggSQL;
	/*
	 * Handle to the subsystem manager of the server.
	 */
	JDPSubsystemMgr manager;
	/*
	 * Handle to the job that this class is running in.
	 */
	JDPJob thisJob;

	/**
	 * Creates a new module that runs on the server and can be accessed 
	 * by other modules or by remote clients.
	 * @param manager the handle to the subsystem manager.
	 * @param thisJob the handle to the job in which this class runs.
	 */
	public ServerPushEntity(JDPSubsystemMgr manager, JDPJob thisJob) {

		this.manager = manager;
		this.thisJob = thisJob;
		thisJob.setInstance(this);

		thisJob.appendJobLog("Job started on " + (new Date()).toString());
		jaggSQL = new JDPJagg(manager.JDPJaggPath);

		MessageSender1 = new JDPServerSender(jaggSQL);
		//
		//  Stay running while the server remains running or until
		//  manually terminated.
		//  
		while (!manager.shutdownRequested) {
			try {
				//
				// Insert repetitive processing here if required
				//
				sendMessages();
				//
				//  Wait 10 seconds until the next repetitve processing
				//  needs to be done
				//
				Thread.sleep(10000);
			} catch (Exception e) {
				ByteArrayOutputStream ErrorOutStream = new ByteArrayOutputStream();
				PrintStream errorStream = new PrintStream((OutputStream)ErrorOutStream);
				e.printStackTrace(errorStream);
				thisJob.appendJobLog(ErrorOutStream.toString());
			}
		}
		
		thisJob.appendJobLog("Job completed on " + (new Date()).toString());

	}



	/*
	 * Get a list of connected users and send a messages to each.
	 */
	void sendMessages() {
	
		String thisMessage = (new Date()).toString();
		MessageSender1.getConnectedClients();
		String[] addresses = MessageSender1.getIPAddresses();

		if (addresses != null) {
			Event thisEvent = new Event(this,Event.ACTION_EVENT,thisMessage);
			for (int ix=0; ix<addresses.length; ix++) {
				MessageSender1.sendEventToClient(addresses[ix], "ServerPushTest", thisEvent);
			}	
		}
	}


}
